OpenPayCardInfo class

Constructors

OpenPayCardInfo({required String name, required String cardNumber, required int expirationMonth, required int expirationYear, required String cvv})
const

Properties

cardNumber String
final
cvv String
final
expirationMonth int
final
expirationYear int
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited