OpenPayCredentials class

Constructors

OpenPayCredentials({required String merchant, required String apiKey, required bool productionMode})
const

Properties

apiKey String
final
hashCode int
The hash code for this object.
no setterinherited
merchant String
final
productionMode bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited